@@ -47,29 +47,26 @@
 
 #![cfg_attr(not(test), no_std)]
 #![cfg_attr(
-    all(not(test), not(feature = "std"), feature = "no-std-helpers"),
+    all(not(test), feature = "no-std-helpers"),
     feature(alloc_error_handler, core_intrinsics, lang_items)
 )]
-#![doc(html_root_url = "https://docs.rs/casper-contract/1.4.1")]
+#![doc(html_root_url = "https://docs.rs/casper-contract/1.4.2")]
 #![doc(
     html_favicon_url = "https://raw.githubusercontent.com/CasperLabs/casper-node/master/images/CasperLabs_Logo_Favicon_RGB_50px.png",
     html_logo_url = "https://raw.githubusercontent.com/CasperLabs/casper-node/master/images/CasperLabs_Logo_Symbol_RGB.png",
     test(attr(forbid(warnings)))
 )]
 #![warn(missing_docs)]
-
 extern crate alloc;
-#[cfg(feature = "std")]
-extern crate std;
 
 pub mod contract_api;
 pub mod ext_ffi;
-#[cfg(all(not(test), not(feature = "std"), feature = "no-std-helpers"))]
+#[cfg(all(not(test), feature = "no-std-helpers", not(feature = "std")))]
 mod no_std_handlers;
 pub mod unwrap_or_revert;
 
 /// An instance of [`WeeAlloc`](https://docs.rs/wee_alloc) which allows contracts built as `no_std`
 /// to avoid having to provide a global allocator themselves.
-#[cfg(all(not(test), not(feature = "std"), feature = "no-std-helpers"))]
+#[cfg(all(not(test), feature = "no-std-helpers"))]
 #[global_allocator]
 pub static ALLOC: wee_alloc::WeeAlloc = wee_alloc::WeeAlloc::INIT;
